@@ -21,6 +21,7 @@ arg_enum! {
         OperatingSystem,
         DesktopEnvironment,
         WindowManager,
+        Resolution,
         Packages,
         Shell,
         Terminal,
@@ -214,6 +215,13 @@ pub fn get_all_readouts<'a>(
         }
     }
 
+    if should_display.contains(&ReadoutKey::Resolution) {
+        match general_readout.resolution() {
+            Ok(r) => readout_values.push(Readout::new(ReadoutKey::Resolution, r)),
+            Err(e) => readout_values.push(Readout::new_err(ReadoutKey::Resolution, e)),
+        }
+    }
+
     if should_display.contains(&ReadoutKey::Terminal) {
         match general_readout.terminal() {
             Ok(s) => readout_values.push(Readout::new(ReadoutKey::Terminal, s)),
